@@ -1,6 +1,7 @@
 /*
 * board.cpp
 */
+#include <vector>
 
 #include "config.h"
 #include "setting.h"
@@ -34,6 +35,7 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	showCoords = setting->readBoolEntry("BOARD_COORDS");
 	showSGFCoords = setting->readBoolEntry("SGF_BOARD_COORDS");
 	antiClicko = setting->readBoolEntry("ANTICLICKO");
+
 	
 	// Create a BoardHandler instance.
 	boardHandler = new BoardHandler(this);
@@ -50,6 +52,8 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	canvas->resize(BOARD_X, BOARD_Y);
 	setCanvas(canvas);
 	
+	gatter = new Gatter(canvas, board_size);
+
 	// Init data storage for marks and ghosts
 	marks = new QPtrList<Mark>;
 	marks->setAutoDelete(TRUE);
@@ -60,6 +64,7 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	
 	// Init the gatter size and the imagehandler pixmaps
 	calculateSize();
+
 	imageHandler->init(square_size);
 	
 	// Initialize some class variables
@@ -73,6 +78,7 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 			letterPool[i] = false;
 		numberPool[i] = false;
 	}
+	
 	//coordsTip = new Tip(this);
 #ifdef Q_WS_WIN
 	resizeDelayFlag = false;
@@ -91,6 +97,7 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	navIntersectionStatus = false;
   
 	updateCaption();
+	gatter_created = false;
 }
 
 Board::~Board()
@@ -175,7 +182,7 @@ void Board::resizeBoard(int w, int h)
     for(it = list.begin(); it != list.end(); ++it)
     {
 		item = *it;
-		if (item->rtti() == 6 || item->rtti() == 7 || item->rtti() == 3)
+		if (item->rtti() == 3)// || item->rtti() == 6)// || item->rtti() == 7)
 		{
 			item->hide();
 			delete item;
@@ -214,6 +221,7 @@ void Board::resizeBoard(int w, int h)
 	// Redraw the board
 	drawBackground();
 	drawGatter();
+	
 	if (showCoords)
 		drawCoordinates();
 
@@ -333,9 +341,12 @@ void Board::drawBackground()
 
 void Board::drawGatter()
 {
-	QCanvasLine *line;
-	int i;
+/*	QCanvasLine *line;
+	int i,j;
 	
+	static QCanvasLine  *VGatter[361];
+	static QCanvasLine  *HGatter[361];
+
 	// Draw vertical lines
 	for (i=0; i<board_size; i++)
 	{
@@ -353,7 +364,9 @@ void Board::drawGatter()
 			offsetX + board_pixel_size, offsetY + square_size * i);
 		line->show();
 	}
-	
+	*/
+	gatter->resize(offsetX,offsetY,square_size);
+/*
 	// Draw the little circles on the starpoints
 	int edge_dist = (board_size > 12 ? 4 : 3);
 	int low = edge_dist;
@@ -372,7 +385,7 @@ void Board::drawGatter()
 	drawStarPoint(low, high);
 	drawStarPoint(high, low);
 	drawStarPoint(high, high);
-
+*/
 	updateCanvas();
 }
 
@@ -965,6 +978,9 @@ void Board::hideAllMarks()
 {
     MarkText::maxLength = 1;
     marks->clear();
+		
+    gatter->showAll();
+
     for (int i=0; i<400; i++)
     {
 		if (i < 52)
@@ -1041,7 +1057,7 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 		return;
 	
     Mark *m;
-	
+
     // We already have a mark on this spot? If it is of the same type,
     // do nothing, else overwrite with the new mark.
     if ((m = hasMark(x, y)) != NULL)
@@ -1111,7 +1127,7 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 				letterPool[n] = true;
 		}
 		m = new MarkText(imageHandler, x, y, square_size, txt, canvas, col, n, false, overlay);
-		//setMarkText(x, y, txt);
+		gatter->hide(x,y);//setMarkText(x, y, txt);
 		break;
 		
     case markNumber:
@@ -1131,6 +1147,7 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 		numberPool[n] = true;
 		m = new MarkNumber(imageHandler, x, y, square_size, n, canvas, col, false);
 		setMarkText(x, y, txt);
+		gatter->hide(x,y);
 		break;
 		
     case markTerrBlack:
@@ -1195,6 +1212,7 @@ void Board::removeMark(int x, int y, bool update)
 			}
 			
 			marks->remove(m);
+			gatter->show(x,y);
 			if (update)
 				boardHandler->editMark(x, y, markNone);
 			return;
@@ -1647,3 +1665,155 @@ QString Board::getCandidateFileName()
 	} 
 	return dir + result + ".sgf";
 }
+
+ /**
+ * Initialises the gatter intersections and hoshis points
+ **/
+Gatter::Gatter(QCanvas *Canvas, int size)
+{
+	int i,j;
+
+	board_size = size;
+	canvas=Canvas;	
+
+	VGatter.reserve(board_size);
+	HGatter.reserve(board_size);
+	for (i=0; i<board_size; i++)
+	{	
+		std::vector<QCanvasLine *> row,col;
+		row.reserve(board_size);
+		col.reserve(board_size);
+		VGatter.push_back(row);
+		HGatter.push_back(col);
+		
+		for (j=0; j<board_size; j++)
+		{
+			VGatter[i].push_back(new QCanvasLine(canvas));
+			HGatter[i].push_back(new QCanvasLine(canvas));
+			CHECK_PTR(VGatter[i][j]);
+			CHECK_PTR(HGatter[i][j]);
+		}
+	}
+	
+	int edge_dist = (board_size > 12 ? 4 : 3);
+	int low = edge_dist;
+	int middle = (board_size + 1) / 2;
+	int high = board_size + 1 - edge_dist;
+	if (board_size % 2 && board_size > 9)
+	{
+		hoshisList.insert(middle*board_size + low , new QCanvasEllipse(canvas));
+		hoshisList.insert(middle*board_size + middle , new QCanvasEllipse(canvas));
+		hoshisList.insert(middle*board_size + high , new QCanvasEllipse(canvas));
+		hoshisList.insert(low*board_size + middle , new QCanvasEllipse(canvas));
+		hoshisList.insert(high*board_size + middle , new QCanvasEllipse(canvas));
+	}
+	hoshisList.insert(low*board_size + low ,new QCanvasEllipse(canvas));
+	hoshisList.insert(high*board_size + low , new QCanvasEllipse(canvas));
+	hoshisList.insert(high*board_size + high , new QCanvasEllipse(canvas));
+	hoshisList.insert(low*board_size + high ,new QCanvasEllipse(canvas));
+
+	QIntDictIterator<QCanvasEllipse> it( hoshisList );
+	for ( ; it.current(); ++it )
+        	it.current()->setBrush(Qt::black);
+
+	showAll();
+}
+
+ /**
+ * Calculates the gatter intersections and hoshis position
+ **/
+void Gatter::resize(int offsetX, int offsetY, int square_size)
+{
+	int i,j;
+	QCanvasEllipse *e;
+
+	int size = square_size / 5;
+	// Round size top be even
+	if (size % 2 > 0)
+		size--;
+	if (size < 6)
+		size = 6;
+
+
+	for (i=0; i<board_size; i++)
+		for (j=0; j<board_size; j++)
+		{
+			HGatter[i][j]->setPoints(int(offsetX + square_size * ( i - 0.5*(i!=0))), 
+						offsetY + square_size * j,
+						int(offsetX + square_size * ( i + 0.5 * (i+1 != board_size))), 
+						offsetY + square_size * j );
+			
+			VGatter[i][j]->setPoints(offsetX + square_size *  i, 
+						int(offsetY + square_size * ( j - 0.5*(j!=0))),
+						offsetX + square_size *  i, 
+						int(offsetY + square_size * ( j + 0.5 * (j+1 != board_size)))); 
+			
+			e=hoshisList.find(board_size*(i+1)+j+1);
+			if (e)
+			{
+				e->setSize(size, size);
+    				e->setX(offsetX + square_size * i);
+    				e->setY(offsetY + square_size * j);
+			}
+		}
+
+}
+
+ /**
+ * Resets all interctions and hoshis to be shown
+ **/
+void Gatter::showAll()
+{
+	int i,j;
+	QCanvasEllipse *e;
+
+	for (i=0; i<board_size; i++)
+		for (j=0; j<board_size; j++)
+		{
+			VGatter[i][j]->show();
+			HGatter[i][j]->show();
+		}
+
+	QIntDictIterator<QCanvasEllipse> it( hoshisList );
+	for ( ; it.current(); ++it )
+        	it.current()->show();
+}
+
+ /**
+ * Hides an intersection (when placing a letter mark)
+ **/
+void Gatter::hide(int i, int j)
+{
+	QCanvasEllipse *e;
+	
+	if (( i<1) || (i > board_size) || ( j<1) || (j > board_size))
+		return;
+
+	VGatter[i-1][j-1]->hide();
+	HGatter[i-1][j-1]->hide();
+
+	e=hoshisList.find(board_size*i+j);
+	if (e)
+		e->hide();
+
+}
+
+ /**
+ * shows an intersection (when removing a letter mark)
+ **/
+void Gatter::show(int i, int j)
+{
+	QCanvasEllipse *e;
+
+	if (( i<1) || (i > board_size) || ( j<1) || (j > board_size))
+		return;
+
+	VGatter[i-1][j-1]->show();
+	HGatter[i-1][j-1]->show();
+
+	e=hoshisList.find(board_size*i+j);
+	if (e)
+		e->show();
+
+}
+
