@@ -59,7 +59,7 @@ bool Group::isAttachedTo(Stone *s)
 #ifndef NO_DEBUG
 void Group::debug()
 {
-	qDebug(QString("Count: %1").arg(count()));
+	qDebug(QString("Count: %1 - Liberties: %2").arg(count()).arg(liberties));
 	Stone *s;
 
 	QListIterator<Stone> it(*this);
@@ -69,6 +69,6 @@ void Group::debug()
 		s = it.current();
 		qDebug(" (%d, %d) %s", s->posX(), s->posY(),
 		s->getColor() == stoneBlack ? "B" : "W");
-    }	
+	}	
 }
 #endif
