@@ -9,7 +9,7 @@
 
 
 // maybe this should be elsewhere ...
-typedef void (*callBackFP_t)(const char*, unsigned);
+typedef void (*callBackFP_t)(QString);
 
 template <class T>  class callBackImpl 
 {
@@ -36,10 +36,10 @@ public:
 	virtual ~IGSInterface()	{ }
 	
 	virtual bool isConnected()=0;
-	virtual bool openConnection(const char *host, unsigned port,
-		const char *user=0, const char *pass=0)=0;
+	virtual bool openConnection(const char *host, unsigned port, const char *user=0, const char *pass=0)=0;
 	virtual bool closeConnection()=0;
-	virtual void sendTextToHost(const char *txt)=0;
+	virtual void sendTextToHost(QString, bool)=0;
 	virtual const char* getUsername()=0;
+	virtual void setTextCodec(QString)=0;
 };
 #endif
