@@ -20,10 +20,10 @@
 #include <qslider.h>
 #include <qtabwidget.h>
 
-#ifdef USE_XPM
+//#ifdef USE_XPM
 #include ICON_NODE_BLACK
 #include ICON_NODE_WHITE
-#endif
+//#endif
 
 struct ButtonState
 {
@@ -387,20 +387,20 @@ void InterfaceHandler::setMarkType(int m)
 		if (board->getBoardHandler()->getBlackTurn())
 		{
 			current->setPLinfo(stoneWhite);
-#ifndef USE_XPM
-			mainWidget->colorButton->setPixmap(QPixmap(ICON_NODE_WHITE));
-#else
+//#ifndef USE_XPM
+//			mainWidget->colorButton->setPixmap(QPixmap(ICON_NODE_WHITE));
+//#else
 			mainWidget->colorButton->setPixmap(QPixmap(const_cast<const char**>(node_white_xpm)));
-#endif
+//#endif
 		}
 		else
 		{
 			current->setPLinfo(stoneBlack);
-#ifndef USE_XPM
-			mainWidget->colorButton->setPixmap(QPixmap(ICON_NODE_BLACK));
-#else
+//#ifndef USE_XPM
+//			mainWidget->colorButton->setPixmap(QPixmap(ICON_NODE_BLACK));
+//#else
 			mainWidget->colorButton->setPixmap(QPixmap(const_cast<const char**>(node_black_xpm)));
-#endif
+//#endif
 		}
 
 		// check if set color is natural color:
