@@ -32,10 +32,10 @@ public slots:
 	void slot_toolsTabChanged(QWidget*);
 	virtual void setMarkType(int);
 	virtual void doPass();
-	virtual void doUndo() { interfaceHandler->board->doUndo(); }
-	virtual void doAdjourn() { interfaceHandler->board->doAdjourn(); }
-	virtual void doResign() { interfaceHandler->board->doResign(); }
-	virtual void doRefresh() { interfaceHandler->board->doRefresh(); }
+	virtual void doUndo();// { interfaceHandler->board->doUndo(); }
+	virtual void doAdjourn();// { interfaceHandler->board->doAdjourn(); }
+	virtual void doResign();// { interfaceHandler->board->doResign(); }
+	virtual void doRefresh();// { interfaceHandler->board->doRefresh(); }
 	virtual void doScore(bool);
 	virtual void sliderChanged(int);
 	
