@@ -45,6 +45,8 @@
 #include <qobjectlist.h> 
 #include <qlistbox.h> 
 #include <qmovie.h> 
+#include <qradiobutton.h>
+
 #ifndef QGO_NOSTYLES
 #include <qplatinumstyle.h>
 #include <qmotifstyle.h>
@@ -389,6 +391,8 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	// create qGo Interface for board handling
 	qgoif = new qGoIF(this);
 	// qGo Interface
+	
+	connect(parser, SIGNAL(signal_set_observe( const QString&)), qgoif, SLOT(set_observe(const QString&)));
 	connect(parser, SIGNAL(signal_move(GameInfo*)), qgoif, SLOT(slot_move(GameInfo*)));
 	connect(parser, SIGNAL(signal_move(Game*)), qgoif, SLOT(slot_move(Game*)));
 	connect(parser, SIGNAL(signal_kibitz(int, const QString&, const QString&)), qgoif, SLOT(slot_kibitz(int, const QString&, const QString&)));
@@ -965,11 +969,15 @@ void ClientWindow::sendTextToApp(const QString &txt)
 					// set id - only available if registerd; who knows why...
 					sendcommand("id qGo " + QString(VERSION), true);
 					sendcommand("toggle newrating");
-					sendcommand("toggle nmatch");
+//					if (setting->readBoolEntry("USE_NMATCH"))
+//					{
+// we wanted to allow user to disable 'nmatch', but IGS disables 'seek' with nmatch
+						sendcommand("toggle nmatch");
+
+						//temporaary settings to prevent use of Koryo BY on IGS (as opposed to canadian)
+						sendcommand("nmatchrange BWN 0-9 19-19 60-60 60-3600 25-25 0 0 0-0",false);
+//					}
 					sendcommand("toggle newundo");
-					//temporaary settings to prevent use of Koryo BY on IGS (as opposed to canadian)
-					sendcommand("nmatchrange BWN 0-9 19-19 60-60 60-3600 25-25 0 0 0-0",false);
-					
 					sendcommand("toggle seek");
 					sendcommand("seek config_list ");
 					sendcommand("room");
@@ -1307,7 +1315,7 @@ qDebug("cmd_valid: %i", (int)cmd_valid);
 			testcmd = element(cmdLine, 1, " ");
 			if (testcmd)
 			{
-				qgoif->set_observe(testcmd);
+//				qgoif->set_observe(testcmd);
 				sendcommand("games " + testcmd);
 			}
 		}
@@ -1657,6 +1665,11 @@ void ClientWindow::slot_pbrefreshplayers()
 
 void ClientWindow::slot_gamesPopup(int i)
 {
+
+	QString player_nameW = (lv_popupGames->text(1).right(1) == "*" ? lv_popupGames->text(1).left( lv_popupGames->text(1).length() -1 ):lv_popupGames->text(1));
+
+	QString player_nameB = (lv_popupGames->text(3).right(1) == "*" ? lv_popupGames->text(3).left( lv_popupGames->text(3).length() -1 ):lv_popupGames->text(3));
+
 	switch (i)
 	{
 		case 1:
@@ -1664,7 +1677,7 @@ void ClientWindow::slot_gamesPopup(int i)
 			if (lv_popupGames)
 			{
 				// set up game for observing
-				if (qgoif->set_observe(lv_popupGames->text(0)))
+				//if (qgoif->set_observe(lv_popupGames->text(0)))
 				{
 					QString gameID = lv_popupGames->text(0);
 					// if game is set up new -> get moves
@@ -1706,12 +1719,12 @@ void ClientWindow::slot_gamesPopup(int i)
 
 		case 2:
 			// stats
-			slot_sendcommand("stats " + lv_popupGames->text(1), false);
+			slot_sendcommand("stats " + player_nameW, false);
 			break;
 
 		case 3:
 			// stats
-			slot_sendcommand("stats " + lv_popupGames->text(3), false);
+			slot_sendcommand("stats " + player_nameB, false);
 			break;
 
 		default:
@@ -1801,7 +1814,7 @@ void ClientWindow::slot_removeMatchDialog(const QString &opponent)
 	// seek dialog
 		// look for same opponent
 	dlg = matchlist.first();
-	while (dlg && dlg->playerWhiteEdit->text() != opponent && dlg->playerBlackEdit->text() != opponent)
+	while (dlg && dlg->playerOpponentEdit->text() != opponent ) //&& dlg->playerBlackEdit->text() != opponent)
 		dlg = matchlist.next();
 
 	if (dlg)
@@ -1836,7 +1849,7 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 
 	// look for same opponent
 	dlg = matchlist.first();
-	while (dlg && dlg->playerWhiteEdit->text() != opponent && dlg->playerBlackEdit->text() != opponent)
+	while (dlg && dlg->playerOpponentEdit->text() != opponent)// && dlg->playerBlackEdit->text() != opponent)
 		dlg = matchlist.next();
 
 	if (!dlg)
@@ -1899,32 +1912,38 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		QString rk = element(line, 1, " ");
 
 		// set values
-		dlg->playerWhiteEdit->setText(myAccount->acc_name);
+		/*dlg->playerWhiteEdit->setText(myAccount->acc_name);
 		dlg->playerWhiteEdit->setReadOnly(true);
 		dlg->playerBlackEdit->setText(opponent);
 		dlg->playerBlackEdit->setReadOnly(false);
+		*/
+		dlg->playerOpponentEdit->setText(opponent);		
+		dlg->playerOpponentEdit->setReadOnly(true);
+		dlg->set_myName( myAccount->acc_name);
 
 		// set my and opponent's rank for suggestion
 		dlg->set_oppRk(rk);
-		dlg->playerBlackRkEdit->setText(rk);
+		dlg->playerOpponentRkEdit->setText(rk);
 		rk = myAccount->get_rank();
 		dlg->set_myRk(rk);
-		dlg->playerWhiteRkEdit->setText(rk);
+		//dlg->playerWhiteRkEdit->setText(rk);
 		dlg->set_gsName(myAccount->get_gsname());
 		dlg->handicapSpin->setEnabled(false);
 
 		dlg->buttonDecline->setDisabled(true);
-
+		
 		// my request: free/rated game is also requested
 		//dlg->cb_free->setChecked(true);
 
 		// teaching game:
-		if (dlg->playerWhiteEdit->text() == dlg->playerBlackEdit->text())
+		if (dlg->playerOpponentEdit->text() == myAccount->acc_name)
 			dlg->buttonOffer->setText(tr("Teaching"));
 
 		//nmatch settings from opponent 
-		dlg->set_is_nmatch(lv_popupPlayer->nmatch);
-		if ( (lv_popupPlayer->nmatch) && (lv_popupPlayer->nmatch_settings ))
+		bool is_nmatch = (lv_popupPlayer->nmatch)&&setting->readBoolEntry("USE_NMATCH");
+		dlg->set_is_nmatch(is_nmatch);
+
+		if ( (is_nmatch) && (lv_popupPlayer->nmatch_settings ))
 		{
 			dlg->timeSpin->setRange((int)(lv_popupPlayer->nmatch_timeMin/60), (int)(lv_popupPlayer->nmatch_timeMax/60));
 			dlg->byoTimeSpin->setRange((int)(lv_popupPlayer->nmatch_BYMin/60), (int)(lv_popupPlayer->nmatch_BYMax/60));
@@ -1938,6 +1957,7 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		}
 		//no handicap with usual game requests
 		dlg->handicapSpin->setEnabled(lv_popupPlayer->nmatch);
+		dlg->play_nigiri_button->setEnabled(lv_popupPlayer->nmatch);
 
 		//default settings
 		dlg->boardSizeSpin->setValue(setting->readIntEntry("DEFAULT_SIZE"));
@@ -1951,6 +1971,8 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 	{
 		// match xxxx B 19 1 10 - using this line means: I am black!
 		bool opp_plays_white = (element(line, 2, " ") == "B");//QString(tr("B")));
+		bool opp_plays_nigiri = (element(line, 2, " ") == "N");
+
 		QString handicap, size, time,byotime, byostones ;
 
 		if (line.contains("nmatch"))
@@ -1984,6 +2006,7 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 			dlg->byoTimeSpin->setRange(0,100);
 			dlg->byoTimeSpin->setValue(byotime.toInt());
 			dlg->handicapSpin->setEnabled(false);
+			dlg->play_nigiri_button->setEnabled(false);
 			dlg->boardSizeSpin->setRange(1,19);
 			dlg->boardSizeSpin->setValue(size.toInt());
 		}
@@ -1994,24 +2017,37 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		QString myrk = myAccount->get_rank();
 		dlg->set_myRk(myrk);
 
+		dlg->playerOpponentEdit->setText(opponent);		
+		dlg->playerOpponentEdit->setReadOnly(true);		
+		dlg->playerOpponentRkEdit->setText(rk);
+		dlg->set_myName( myAccount->acc_name);
+
 		if (opp_plays_white)
 		{
-			dlg->playerBlackEdit->setText(myAccount->acc_name);
+/*			dlg->playerBlackEdit->setText(myAccount->acc_name);
 			dlg->playerBlackEdit->setReadOnly(true);
 			dlg->playerBlackRkEdit->setText(myAccount->get_rank());
 			dlg->playerWhiteEdit->setText(opponent);
 			dlg->playerWhiteEdit->setReadOnly(false);
 			dlg->playerWhiteRkEdit->setText(rk);
+*/
+			dlg->play_black_button->setChecked(true);
+
+
 		}
-		else
+		else if (opp_plays_nigiri)
 		{
-			dlg->playerWhiteEdit->setText(myAccount->acc_name);
+/*			dlg->playerWhiteEdit->setText(myAccount->acc_name);
 			dlg->playerWhiteEdit->setReadOnly(true);
 			dlg->playerWhiteRkEdit->setText(myAccount->get_rank());
 			dlg->playerBlackEdit->setText(opponent);
 			dlg->playerBlackEdit->setReadOnly(false);
 			dlg->playerBlackRkEdit->setText(rk);
+*/
+			dlg->play_nigiri_button->setChecked(true);
 		}
+		else
+			dlg->play_white_button->setChecked(true);		
 
 		dlg->buttonDecline->setEnabled(true);
 		dlg->buttonOffer->setText(tr("Accept"));
@@ -2069,6 +2105,11 @@ void ClientWindow::slot_playerPopup(int i)
 			slot_sendcommand("result " + player_name, false);
 			break;
 
+		case 12:
+			// trail
+			slot_sendcommand("trail " + player_name, false);
+			break;
+
 		case 6:
 		{
 			// toggle watch list
@@ -2210,7 +2251,7 @@ void ClientWindow::slot_playerPopup(int i)
 //				slot_game(&g);
 
 				// observe
-				if (qgoif->set_observe(g.nr))
+//				if (qgoif->set_observe(g.nr))
 					sendcommand("observe " + g.nr, false);
 //				sendcommand("games " + g.nr, false);
 			}
@@ -2238,7 +2279,8 @@ void ClientWindow::slot_click_players(QListViewItem *lv)
 void ClientWindow::slot_menu_players(QListViewItem *lv, const QPoint& pt, int)
 {
 	// emulate right button
-	slot_mouse_players(2, lv, pt, 0);
+	if (lv)
+		slot_mouse_players(2, lv, pt, 0);
 }
 // mouse click on ListView_players
 void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoint& /*pt */, int /*column*/)
@@ -2258,6 +2300,7 @@ void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoin
 		puw->insertItem(tr("results"), this, SLOT(slot_playerPopup(int)), 0, 5);
 		puw->insertItem(tr("rating"), this, SLOT(slot_playerPopup(int)), 0, 8);
 		puw->insertItem(tr("observe game"), this, SLOT(slot_playerPopup(int)), 0, 9);
+		puw->insertItem(tr("trail"), this, SLOT(slot_playerPopup(int)), 0, 12);
 		puw->insertSeparator();
 		puw->insertItem(tr("toggle watch list"), this, SLOT(slot_playerPopup(int)), 0, 6);
 		puw->insertItem(tr("toggle exclude list"), this, SLOT(slot_playerPopup(int)), 0, 7);
@@ -2266,7 +2309,7 @@ void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoin
 	
 	puw->setItemEnabled(11,lv_popupPlayer->nmatch);
 //puw->hide();
-
+	
 	// do actions if button clicked on item
 	switch (button)
 	{
