@@ -166,7 +166,7 @@ public slots:
 	void slot_addToObservationList(int);
 	void slot_channelinfo(int, const QString&);
 	void slot_matchrequest(const QString&, bool);
-  	void slot_matchCanceled(const QString&);
+  	void slot_removeMatchDialog(const QString&);
 	void slot_shout(const QString&, const QString&);
 	void slot_room(const QString&, bool );
 	void slot_enterRoom(const QString& );
@@ -203,7 +203,8 @@ public slots:
 	void slotHelpManual();
 	void slotHelpSoundInfo();
 	void slotHelpAbout();
-	void slotHelpAboutQt();                           
+	void slotHelpAboutQt();
+	void slotNewVersion();
 
 	void slotMenuConnect();
 	void slotMenuDisconnect();
