@@ -1170,8 +1170,8 @@ void MainWindow::slotFileNewGame()
 			d->size = dlg.boardSizeSpin->value();
 			d->komi = (float)dlg.komiSpin->value() / 10.0;
 			d->handicap = dlg.handicapSpin->value();
-			d->playerBlack = dlg.playerBlackEdit->text();
-			d->playerWhite = dlg.playerWhiteEdit->text();
+//			d->playerBlack = dlg.playerBlackEdit->text();
+//			d->playerWhite = dlg.playerWhiteEdit->text();
 			d->gameName = "";
 			d->gameNumber = 0;
 			d->fileName = "";
@@ -1275,8 +1275,8 @@ bool MainWindow::slotFileSave()
 
 bool MainWindow::slotFileSaveAs()
 {
-	if (setting->readBoolEntry("REM_DIR"))
-		return doSave(setting->readEntry("LAST_DIR"), false);
+//	if (setting->readBoolEntry("REM_DIR"))
+//		return doSave(setting->readEntry("LAST_DIR"), false);
 	return doSave(0, false);
 }
 
@@ -1651,6 +1651,7 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.LineEdit_watch->setText(setting->readEntry("WATCH"));
 	dlg.LineEdit_exclude->setText(setting->readEntry("EXCLUDE"));
 	dlg.CheckBox_extUserInfo->setChecked(setting->readBoolEntry("EXTUSERINFO"));
+//	dlg.CheckBox_useNmatch->setChecked(setting->readBoolEntry("USE_NMATCH"));
 	dlg.LineEdit_computer->setText(setting->readEntry("COMPUTER_PATH")); //SL added eb 12
 	dlg.computerButtonWhite->setChecked(setting->readBoolEntry("COMPUTER_WHITE"));
 	dlg.computerButtonBlack->setChecked(setting->readBoolEntry("COMPUTER_BLACK"));
@@ -1751,6 +1752,7 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeEntry("WATCH", dlg->LineEdit_watch->text());
 	setting->writeEntry("EXCLUDE", dlg->LineEdit_exclude->text());
 	setting->writeBoolEntry("EXTUSERINFO", dlg->CheckBox_extUserInfo->isChecked());
+//	setting->writeBoolEntry("USE_NMATCH", dlg->CheckBox_useNmatch->isChecked());
 	setting->writeIntEntry("DEFAULT_SIZE", dlg->boardSizeSpin->text().toInt());
 	setting->writeIntEntry("DEFAULT_TIME", dlg->timeSpin->text().toInt());
 	setting->writeIntEntry("DEFAULT_BY", dlg->BYSpin->text().toInt());
