@@ -34,7 +34,7 @@ public:
 	~MainWindow();
 	InterfaceHandler* getInterfaceHandler() const { return interfaceHandler; }
 	Board* getBoard() const { return board; }
-	void setApplicationStyle();
+//	void setApplicationStyle();
 	bool preferencesAccept();
 	void doOpen(const QString &fileName, const QString &filter=0, bool storedir=true);
 	bool startComputerPlay(QNewGameDlg * dlg,const QString &fileName, const QString &filter, const QString &computer_path);
@@ -138,13 +138,14 @@ public slots:
 	void slotTimerForward();
 	void slot_editBoardInNewWindow();
 	void slot_animateClick();
+	void slotSoundToggle(bool toggle);
 
 private:
 	qGoIF *parent_;
 	Board *board;
 	InterfaceHandler *interfaceHandler;
 	MainWidget *mainWidget;
-  QString style;
+  	QString style;
 	
 	//	HelpViewer *helpViewer;
 	StatusTip *statusTip;
@@ -165,13 +166,13 @@ private:
 		*fileImportASCII, *fileImportASCIIClipB,*fileExportASCII,
 		*fileImportSgfClipB, *fileExportSgfClipB,
 		*fileExportPic, *fileExportPicClipB,
-		*fileQuit;
+		*fileQuit ;
 	QAction *editCut, *editPaste, *editPasteBrother, *editDelete, *editNumberMoves, *editMarkBrothers,
 		*editMarkSons;
 	QAction *navBackward, *navForward, *navFirst, *navLast, *navNextVar, *navPrevVar,
 		*navMainBranch, *navStartVar, *navNextBranch, *navNthMove, *navAutoplay, *navEmptyBranch,
 		*navCloneNode, *navSwapVariations, *navNextComment, *navPrevComment, *navIntersection ;       //SL added eb 11                               // added eb the 2 last
-	QAction *setPreferences, *setGameInfo;
+	QAction *setPreferences, *setGameInfo, *soundToggle;
 	QAction *viewFileBar, *viewToolBar, *viewEditBar, *viewMenuBar, *viewStatusBar, *viewCoords,
 		*viewSlider, *viewSidebar, *viewComment, *viewVertComment, *viewPinComment, *viewIncreaseSize,
 		*viewDecreaseSize, *viewSaveSize, *viewFullscreen;
