@@ -1192,7 +1192,7 @@ qDebug("parser->case 9: Use adjourn to");
 					emit signal_removestones(0, aGameInfo->nr);
 					memory_str = QString();
 				}
-				else if ((memory_str || gsName == IGS) && (aGameInfo->bname == myname || aGameInfo->wname == myname))
+				else if ((memory_str || gsName == IGS || gsName == WING ) && (aGameInfo->bname == myname || aGameInfo->wname == myname))
 				{
 					// if a stored game is restarted then send start message first
 					// -> continuation of case 9
@@ -1248,6 +1248,7 @@ qDebug("parser->case 9: Use adjourn to");
 				aGameInfo->mv_col = element(line, 0, "(", ")");
 			}
 
+			emit signal_set_observe(aGameInfo->nr);
 			emit signal_move(aGameInfo);
 			return MOVE;
 			break;
