@@ -5,6 +5,8 @@
 #ifndef PLAYERTABLE_H
 #define PLAYERTABLE_H
 
+#include "tables.h"
+
 #include <qvariant.h>
 #include <qlistview.h>
 
@@ -17,7 +19,8 @@ public:
 	PlayerTable(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0);
 	~PlayerTable() {};
 //	virtual void setSorting ( int column, bool ascending = TRUE );
-	
+	void showOpen(bool show);
+
 public slots:
 	virtual void slot_mouse_players(int, QListViewItem*, const QPoint&, int) {};
 	
@@ -42,7 +45,20 @@ public:
 
 	void ownRepaint();
 	void replace() ;
-	
+	void set_nmatchSettings(Player *p);
+
+	bool nmatch;
+
+	// BWN 0-9 19-19 60-60 600-600 25-25 0-0 0-0 0-0
+	bool nmatch_black, nmatch_white, nmatch_nigiri, nmatch_settings;
+	int 	nmatch_handicapMin, nmatch_handicapMax, 
+		nmatch_timeMin, nmatch_timeMax, 
+		nmatch_BYMin, nmatch_BYMax, 
+		nmatch_stonesMin, nmatch_stonesMax,
+		nmatch_KoryoMin, nmatch_KoryoMax;
+
+	//bool isOpen() {return open;}
+
 protected:
 //	virtual QString key(int, bool) const;
 	virtual int compare( QListViewItem *p, int col, bool ascending ) const;
@@ -53,6 +69,7 @@ protected:
 	bool exclude;
 	bool its_me;
 	bool seeking;
+
 };
 
 #endif // PLAYERTABLE_H
