@@ -127,7 +127,8 @@ PreferencesDialog::PreferencesDialog(QWidget* parent,  const char* name, bool mo
 	// Default codec
 	ComboBox_codec->insertItem("");
 	// The rest by name
-	for(int i = 0; QTextCodec *codec = QTextCodec::codecForIndex(i); ++i)
+	QTextCodec *codec;
+	for(int i = 0; codec = QTextCodec::codecForIndex(i); ++i)
 		ComboBox_codec->insertItem(codec->name());
 }
 
