@@ -43,11 +43,13 @@ public slots:
 	virtual void startHelpMode();
 	virtual void selectFont(int);
 	virtual void selectColor();
+	virtual void selectAltColor();
 	virtual void slot_accept();
 	virtual void slot_reject();
 	virtual void slot_getComputerPath();
 	virtual void slot_getPixmapPath();
 	virtual void slot_getGobanPicturePath();
+	virtual void slot_getTablePicturePath();
 
 private:
 	void          saveSizes();
