@@ -9,7 +9,7 @@
 /*
 * Tip
 */
-
+/* UNUSED
 Tip::Tip(QWidget *parent)
 : QToolTip(parent)
 {
@@ -50,10 +50,29 @@ StatusTip::~StatusTip()
 {
 }
 
-void StatusTip::slotStatusTipCoords(int x, int y, int board_size)
+void StatusTip::slotStatusTipCoords(int x, int y, int board_size, bool SGFCoords)
 {
 	emit clearStatusBar();
-	
-	setText(" " + QString(QChar(static_cast<const char>('A' + (x<9?x:x+1) - 1))) +       // A -> T (skip I)
-		" " + QString::number(board_size-y+1) + " ");                                // 19 -> 1
+	QString t1,t2;	
+
+
+	if(SGFCoords)
+	{
+		t1 = QString(QChar(static_cast<const char>('a' + x-1)));
+		t2 = QString(QChar(static_cast<const char>('a' + y-1)));
+	}
+	else
+	{
+		t1 = QString(QChar(static_cast<const char>('A' + (x<9?x:x+1) - 1)));
+		t2 = QString::number(board_size - y+1);
+	}
+
+	setText(" " + t1 + //QString(QChar(static_cast<const char>('A' + (x<9?x:x+1) - 1))) +       // A -> T (skip I)
+		" " + t2 +//QString::number(board_size-y+1) + 
+		" ");   
+
+
+
+
+                             // 19 -> 1
 }
