@@ -7,7 +7,7 @@
 
 #include <qtooltip.h>
 #include <qlabel.h>
-
+/* UNUSED
 class Tip : public QToolTip
 {
 public:
@@ -17,7 +17,7 @@ public:
 protected:
 	void maybeTip(const QPoint &p);
 };
-
+*/
 class StatusTip : public QLabel
 {
 	Q_OBJECT
@@ -27,7 +27,7 @@ public:
 	virtual ~StatusTip();
 
 public slots:
-	void slotStatusTipCoords(int, int, int);
+	void slotStatusTipCoords(int, int, int,bool);
 
 signals:
 	void clearStatusBar();
